@@ -11,6 +11,7 @@ char *s = N_("A generic project");
 char *s = N_("A generic Python project using automake project management");
 char *s = N_("A generic wxWidgets project");
 char *s = N_("A sample SDL project");
+char *s = N_("A shared or a static library project");
 char *s = N_("Add C++ support:");
 char *s = N_("Add gtk-doc system:");
 char *s = N_("Add internationalization:");
@@ -24,6 +25,7 @@ char *s = N_("Applet Title:");
 char *s = N_("Author:");
 char *s = N_("Basic information");
 char *s = N_("Berkeley Software Distribution License (BSD)");
+char *s = N_("Build library as");
 char *s = N_("Comma-separated, other plugins that this plugin depends on. It could be either primary interface name or plugin location (library:class)");
 char *s = N_("Configure external packages");
 char *s = N_("Configure external packages:");
@@ -48,6 +50,7 @@ char *s = N_("General Public License (GPL)");
 char *s = N_("Generic");
 char *s = N_("Generic (Minimal)");
 char *s = N_("Generic C++");
+char *s = N_("Generic JavaScript");
 char *s = N_("Generic gcj compiled Java");
 char *s = N_("Generic Java (automake)");
 char *s = N_("Generic Python (automake)");
@@ -58,6 +61,7 @@ char *s = N_("Implement plugin interfaces");
 char *s = N_("Interface implemented by the plugin");
 char *s = N_("Interface:");
 char *s = N_("Lesser General Public License (LGPL)");
+char *s = N_("Library");
 char *s = N_("License");
 char *s = N_("Main Class:");
 char *s = N_("Main class");
@@ -66,6 +70,8 @@ char *s = N_("Makefile-based project");
 char *s = N_("Mininum SDL version required");
 char *s = N_("Name of the value to watch");
 char *s = N_("No license");
+char *s = N_("Only Shared");
+char *s = N_("Only Static");
 char *s = N_("Options for project build system");
 char *s = N_("Plugin Class Name:");
 char *s = N_("Plugin Dependencies:");
@@ -95,6 +101,8 @@ char *s = N_("Require SDL_ttf library");
 char *s = N_("Require SDL_ttf:");
 char *s = N_("SDL");
 char *s = N_("Select code license");
+char *s = N_("Select library type to build");
+char *s = N_("Shared and Static library");
 char *s = N_("Shell values to watch");
 char *s = N_("Use pkg-config to add library support from other packages");
 char *s = N_("Value Name:");
